# CV Tron

![logo.png](http://ac-5focnst0.clouddn.com/1a6303279b0a69375abc.png)

[![Build Status](https://travis-ci.org/unarxiv/CVTron.svg?branch=master)](https://travis-ci.org/unarxiv/CVTron)
[![Maintainability](https://api.codeclimate.com/v1/badges/721858de11e15ef33f2a/maintainability)](https://codeclimate.com/github/unarxiv/CVTron/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/721858de11e15ef33f2a/test_coverage)](https://codeclimate.com/github/unarxiv/CVTron/test_coverage)
[![Documentation Status](https://readthedocs.org/projects/cvtron/badge/?version=latest)](http://cvtron.readthedocs.io/en/latest/?badge=latest)
[![Slack](https://img.shields.io/badge/chat-on%20slack-7289da.svg)](https://cvtron.slack.com)

CVTRon is a Computer Vision Library for industry use. It tries to provide an out-of-the-box experience for our customers and help them build on top of commonly used algorithms and models.

Currently in the first version of the CV Tron, it provides image classification, semantic segmentation and object detection services in the box. Users could use it for either training on their own datasets, or use some kind of out-of-the-box models such as VGG net and Inception.

CV Tron also provides both web ui and cli tool for rapid deployment and local tests.

CV Tron is built on top of [TensorFlow](https://github.com/tensorflow/tensorflow) and [TensorLayer](https://github.com/tensorlayer/tensorlayer). 

# Community Support

Get Community Support on [Slack](https://join.slack.com/t/cvtron/shared_invite/enQtMzI3MDMzNjM3NzY2LTY1YWRiZmQwNDE5ODAyYTRhNGFhOGM2OWEzYjVlNzZmZDc0YjMxYmYyMzk2Y2FiYmU4YzhmYTViNjU3ZTJlYjQ)

# Contribution 

Please visit [Contributing guidelines](https://github.com/cv-group/CVTron/blob/master/CONTRIBUTING.md)

# Side Project

If you are looking for the answer to build a server with cvtron built in, you can refer to [CVTron-Serve](https://github.com/cv-group/CVTron-Serve) and [CVTron-Vis](https://github.com/unarxiv/CVTron-Vis). We are still working on the CLI tools for other purposes.
